@@ -28,7 +28,7 @@ template<typename eT>
 inline
 gmm_full<eT>::~gmm_full()
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   arma_type_check(( (is_same_type<eT,float>::value == false) && (is_same_type<eT,double>::value == false) ));
   }
@@ -39,7 +39,7 @@ template<typename eT>
 inline
 gmm_full<eT>::gmm_full()
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   }
 
 
@@ -48,7 +48,7 @@ template<typename eT>
 inline
 gmm_full<eT>::gmm_full(const gmm_full<eT>& x)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init(x);
   }
@@ -60,7 +60,7 @@ inline
 gmm_full<eT>&
 gmm_full<eT>::operator=(const gmm_full<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init(x);
   
@@ -73,7 +73,7 @@ template<typename eT>
 inline
 gmm_full<eT>::gmm_full(const gmm_diag<eT>& x)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init(x);
   }
@@ -85,7 +85,7 @@ inline
 gmm_full<eT>&
 gmm_full<eT>::operator=(const gmm_diag<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init(x);
   
@@ -98,7 +98,7 @@ template<typename eT>
 inline
 gmm_full<eT>::gmm_full(const uword in_n_dims, const uword in_n_gaus)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init(in_n_dims, in_n_gaus);
   }
@@ -110,7 +110,7 @@ inline
 void
 gmm_full<eT>::reset()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init(0, 0);
   }
@@ -122,7 +122,7 @@ inline
 void
 gmm_full<eT>::reset(const uword in_n_dims, const uword in_n_gaus)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init(in_n_dims, in_n_gaus);
   }
@@ -135,7 +135,7 @@ inline
 void
 gmm_full<eT>::set_params(const Base<eT,T1>& in_means_expr, const BaseCube<eT,T2>& in_fcovs_expr, const Base<eT,T3>& in_hefts_expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap     <T1> tmp1(in_means_expr.get_ref());
   const unwrap_cube<T2> tmp2(in_fcovs_expr.get_ref());
@@ -145,26 +145,26 @@ gmm_full<eT>::set_params(const Base<eT,T1>& in_means_expr, const BaseCube<eT,T2>
   const Cube<eT>& in_fcovs = tmp2.M;
   const Mat <eT>& in_hefts = tmp3.M;
   
-  arma_debug_check
+  arma_conform_check
     (
     (in_means.n_cols != in_fcovs.n_slices) || (in_means.n_rows != in_fcovs.n_rows) || (in_fcovs.n_rows != in_fcovs.n_cols) || (in_hefts.n_cols != in_means.n_cols) || (in_hefts.n_rows != 1),
     "gmm_full::set_params(): given parameters have inconsistent and/or wrong sizes"
     );
   
-  arma_debug_check( (in_means.internal_has_nonfinite()), "gmm_full::set_params(): given means have non-finite values" );
-  arma_debug_check( (in_fcovs.internal_has_nonfinite()), "gmm_full::set_params(): given fcovs have non-finite values" );
-  arma_debug_check( (in_hefts.internal_has_nonfinite()), "gmm_full::set_params(): given hefts have non-finite values" );
+  arma_conform_check( (in_means.internal_has_nonfinite()), "gmm_full::set_params(): given means have non-finite values" );
+  arma_conform_check( (in_fcovs.internal_has_nonfinite()), "gmm_full::set_params(): given fcovs have non-finite values" );
+  arma_conform_check( (in_hefts.internal_has_nonfinite()), "gmm_full::set_params(): given hefts have non-finite values" );
   
   for(uword g=0; g < in_fcovs.n_slices; ++g)
     {
-    arma_debug_check( (any(diagvec(in_fcovs.slice(g)) <= eT(0))), "gmm_full::set_params(): given fcovs have negative or zero values on diagonals" );
+    arma_conform_check( (any(diagvec(in_fcovs.slice(g)) <= eT(0))), "gmm_full::set_params(): given fcovs have negative or zero values on diagonals" );
     }
   
-  arma_debug_check( (any(vectorise(in_hefts) <  eT(0))), "gmm_full::set_params(): given hefts have negative values" );
+  arma_conform_check( (any(vectorise(in_hefts) <  eT(0))), "gmm_full::set_params(): given hefts have negative values" );
   
   const eT s = accu(in_hefts);
   
-  arma_debug_check( ((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))), "gmm_full::set_params(): sum of given hefts is not 1" );
+  arma_conform_check( ((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))), "gmm_full::set_params(): sum of given hefts is not 1" );
   
   access::rw(means) = in_means;
   access::rw(fcovs) = in_fcovs;
@@ -181,14 +181,14 @@ inline
 void
 gmm_full<eT>::set_means(const Base<eT,T1>& in_means_expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1> tmp(in_means_expr.get_ref());
   
   const Mat<eT>& in_means = tmp.M;
   
-  arma_debug_check( (arma::size(in_means) != arma::size(means)), "gmm_full::set_means(): given means have incompatible size" );
-  arma_debug_check( (in_means.internal_has_nonfinite()),         "gmm_full::set_means(): given means have non-finite values" );
+  arma_conform_check( (arma::size(in_means) != arma::size(means)), "gmm_full::set_means(): given means have incompatible size" );
+  arma_conform_check( (in_means.internal_has_nonfinite()),         "gmm_full::set_means(): given means have non-finite values" );
   
   access::rw(means) = in_means;
   }
@@ -201,18 +201,18 @@ inline
 void
 gmm_full<eT>::set_fcovs(const BaseCube<eT,T1>& in_fcovs_expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap_cube<T1> tmp(in_fcovs_expr.get_ref());
   
   const Cube<eT>& in_fcovs = tmp.M;
   
-  arma_debug_check( (arma::size(in_fcovs) != arma::size(fcovs)), "gmm_full::set_fcovs(): given fcovs have incompatible size" );
-  arma_debug_check( (in_fcovs.internal_has_nonfinite()),         "gmm_full::set_fcovs(): given fcovs have non-finite values" );
+  arma_conform_check( (arma::size(in_fcovs) != arma::size(fcovs)), "gmm_full::set_fcovs(): given fcovs have incompatible size" );
+  arma_conform_check( (in_fcovs.internal_has_nonfinite()),         "gmm_full::set_fcovs(): given fcovs have non-finite values" );
   
   for(uword i=0; i < in_fcovs.n_slices; ++i)
     {
-    arma_debug_check( (any(diagvec(in_fcovs.slice(i)) <= eT(0))), "gmm_full::set_fcovs(): given fcovs have negative or zero values on diagonals" );
+    arma_conform_check( (any(diagvec(in_fcovs.slice(i)) <= eT(0))), "gmm_full::set_fcovs(): given fcovs have negative or zero values on diagonals" );
     }
   
   access::rw(fcovs) = in_fcovs;
@@ -228,19 +228,19 @@ inline
 void
 gmm_full<eT>::set_hefts(const Base<eT,T1>& in_hefts_expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1> tmp(in_hefts_expr.get_ref());
   
   const Mat<eT>& in_hefts = tmp.M;
   
-  arma_debug_check( (arma::size(in_hefts) != arma::size(hefts)), "gmm_full::set_hefts(): given hefts have incompatible size" );
-  arma_debug_check( (in_hefts.internal_has_nonfinite()),         "gmm_full::set_hefts(): given hefts have non-finite values" );
-  arma_debug_check( (any(vectorise(in_hefts) <  eT(0))),         "gmm_full::set_hefts(): given hefts have negative values"   );
+  arma_conform_check( (arma::size(in_hefts) != arma::size(hefts)), "gmm_full::set_hefts(): given hefts have incompatible size" );
+  arma_conform_check( (in_hefts.internal_has_nonfinite()),         "gmm_full::set_hefts(): given hefts have non-finite values" );
+  arma_conform_check( (any(vectorise(in_hefts) <  eT(0))),         "gmm_full::set_hefts(): given hefts have negative values"   );
   
   const eT s = accu(in_hefts);
   
-  arma_debug_check( ((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))), "gmm_full::set_hefts(): sum of given hefts is not 1" );
+  arma_conform_check( ((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))), "gmm_full::set_hefts(): sum of given hefts is not 1" );
   
   // make sure all hefts are positive and non-zero
   
@@ -284,7 +284,7 @@ inline
 bool
 gmm_full<eT>::load(const std::string name)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   field< Mat<eT> > storage;
   
@@ -293,7 +293,7 @@ gmm_full<eT>::load(const std::string name)
   if( (status == false) || (storage.n_elem < 2) )
     {
     reset();
-    arma_debug_warn_level(3, "gmm_full::load(): problem with loading or incompatible format");
+    arma_warn(3, "gmm_full::load(): problem with loading or incompatible format");
     return false;
     }
   
@@ -308,7 +308,7 @@ gmm_full<eT>::load(const std::string name)
   if( (storage.n_elem != (N_gaus + 2)) || (storage_hefts.n_rows != 1) || (storage_hefts.n_cols != N_gaus) )
     {
     reset();
-    arma_debug_warn_level(3, "gmm_full::load(): incompatible format");
+    arma_warn(3, "gmm_full::load(): incompatible format");
     return false;
     }
   
@@ -324,7 +324,7 @@ gmm_full<eT>::load(const std::string name)
     if( (storage_fcov.n_rows != N_dims) || (storage_fcov.n_cols != N_dims) )
       {
       reset();
-      arma_debug_warn_level(3, "gmm_full::load(): incompatible format");
+      arma_warn(3, "gmm_full::load(): incompatible format");
       return false;
       }
     
@@ -343,7 +343,7 @@ inline
 bool
 gmm_full<eT>::save(const std::string name) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_gaus = means.n_cols;
   
@@ -371,7 +371,7 @@ inline
 Col<eT>
 gmm_full<eT>::generate() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -407,7 +407,7 @@ inline
 Mat<eT>
 gmm_full<eT>::generate(const uword N_vec) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -452,7 +452,7 @@ inline
 eT
 gmm_full<eT>::log_p(const T1& expr, const gmm_empty_arg& junk1, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == true))>::result* junk2) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
   
@@ -460,7 +460,7 @@ gmm_full<eT>::log_p(const T1& expr, const gmm_empty_arg& junk1, typename enable_
   
   const quasi_unwrap<T1> U(expr);
   
-  arma_debug_check( (U.M.n_rows != N_dims), "gmm_full::log_p(): incompatible dimensions" );
+  arma_conform_check( (U.M.n_rows != N_dims), "gmm_full::log_p(): incompatible dimensions" );
   
   return internal_scalar_log_p( U.M.memptr() );
   }
@@ -473,15 +473,15 @@ inline
 eT
 gmm_full<eT>::log_p(const T1& expr, const uword gaus_id, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == true))>::result* junk2) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk2);
   
   const uword N_dims = means.n_rows;
   
   const quasi_unwrap<T1> U(expr);
   
-  arma_debug_check( (U.M.n_rows != N_dims),    "gmm_full::log_p(): incompatible dimensions"            );
-  arma_debug_check( (gaus_id >= means.n_cols), "gmm_full::log_p(): specified gaussian is out of range" );
+  arma_conform_check( (U.M.n_rows != N_dims),    "gmm_full::log_p(): incompatible dimensions"            );
+  arma_conform_check( (gaus_id >= means.n_cols), "gmm_full::log_p(): specified gaussian is out of range" );
   
   return internal_scalar_log_p( U.M.memptr(), gaus_id );
   }
@@ -494,7 +494,7 @@ inline
 Row<eT>
 gmm_full<eT>::log_p(const T1& expr, const gmm_empty_arg& junk1, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == false))>::result* junk2) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
   
@@ -513,7 +513,7 @@ inline
 Row<eT>
 gmm_full<eT>::log_p(const T1& expr, const uword gaus_id, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == false))>::result* junk2) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk2);
   
   const quasi_unwrap<T1> tmp(expr);
@@ -531,7 +531,7 @@ inline
 eT
 gmm_full<eT>::sum_log_p(const Base<eT,T1>& expr) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(expr.get_ref());
   
@@ -548,7 +548,7 @@ inline
 eT
 gmm_full<eT>::sum_log_p(const Base<eT,T1>& expr, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(expr.get_ref());
   
@@ -565,7 +565,7 @@ inline
 eT
 gmm_full<eT>::avg_log_p(const Base<eT,T1>& expr) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(expr.get_ref());
   
@@ -582,7 +582,7 @@ inline
 eT
 gmm_full<eT>::avg_log_p(const Base<eT,T1>& expr, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(expr.get_ref());
   
@@ -599,7 +599,7 @@ inline
 uword
 gmm_full<eT>::assign(const T1& expr, const gmm_dist_mode& dist, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == true))>::result* junk) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   const quasi_unwrap<T1> tmp(expr);
@@ -617,7 +617,7 @@ inline
 urowvec
 gmm_full<eT>::assign(const T1& expr, const gmm_dist_mode& dist, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == false))>::result* junk) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   urowvec out;
@@ -639,14 +639,14 @@ inline
 urowvec
 gmm_full<eT>::raw_hist(const Base<eT,T1>& expr, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1>   tmp(expr.get_ref());
   const Mat<eT>& X = tmp.M;
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_full::raw_hist(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_full::raw_hist(): incompatible dimensions" );
   
-  arma_debug_check( ((dist_mode != eucl_dist) && (dist_mode != prob_dist)), "gmm_full::raw_hist(): unsupported distance mode" );
+  arma_conform_check( ((dist_mode != eucl_dist) && (dist_mode != prob_dist)), "gmm_full::raw_hist(): unsupported distance mode" );
   
   urowvec hist;
   
@@ -663,14 +663,14 @@ inline
 Row<eT>
 gmm_full<eT>::norm_hist(const Base<eT,T1>& expr, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1>   tmp(expr.get_ref());
   const Mat<eT>& X = tmp.M;
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_full::norm_hist(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_full::norm_hist(): incompatible dimensions" );
   
-  arma_debug_check( ((dist_mode != eucl_dist) && (dist_mode != prob_dist)), "gmm_full::norm_hist(): unsupported distance mode" );
+  arma_conform_check( ((dist_mode != eucl_dist) && (dist_mode != prob_dist)), "gmm_full::norm_hist(): unsupported distance mode" );
   
   urowvec hist;
   
@@ -711,7 +711,7 @@ gmm_full<eT>::learn
   const bool           print_mode
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool dist_mode_ok = (dist_mode == eucl_dist) || (dist_mode == maha_dist);
   
@@ -722,15 +722,15 @@ gmm_full<eT>::learn
     || (seed_mode == random_subset)
     || (seed_mode == random_spread);
   
-  arma_debug_check( (dist_mode_ok == false), "gmm_full::learn(): dist_mode must be eucl_dist or maha_dist" );
-  arma_debug_check( (seed_mode_ok == false), "gmm_full::learn(): unknown seed_mode"                        );
-  arma_debug_check( (var_floor < eT(0)    ), "gmm_full::learn(): variance floor is negative"               );
+  arma_conform_check( (dist_mode_ok == false), "gmm_full::learn(): dist_mode must be eucl_dist or maha_dist" );
+  arma_conform_check( (seed_mode_ok == false), "gmm_full::learn(): unknown seed_mode"                        );
+  arma_conform_check( (var_floor < eT(0)    ), "gmm_full::learn(): variance floor is negative"               );
   
   const unwrap<T1>   tmp_X(data.get_ref());
   const Mat<eT>& X = tmp_X.M;
   
-  if(X.is_empty()              )  { arma_debug_warn_level(3, "gmm_full::learn(): given matrix is empty"             ); return false; }
-  if(X.internal_has_nonfinite())  { arma_debug_warn_level(3, "gmm_full::learn(): given matrix has non-finite values"); return false; }
+  if(X.is_empty()              )  { arma_warn(3, "gmm_full::learn(): given matrix is empty"             ); return false; }
+  if(X.internal_has_nonfinite())  { arma_warn(3, "gmm_full::learn(): given matrix has non-finite values"); return false; }
   
   if(N_gaus == 0)  { reset(); return true; }
   
@@ -759,14 +759,14 @@ gmm_full<eT>::learn
   
   if(seed_mode == keep_existing)
     {
-    if(means.is_empty()        )  { arma_debug_warn_level(3, "gmm_full::learn(): no existing means"      ); return false; }
-    if(X.n_rows != means.n_rows)  { arma_debug_warn_level(3, "gmm_full::learn(): dimensionality mismatch"); return false; }
+    if(means.is_empty()        )  { arma_warn(3, "gmm_full::learn(): no existing means"      ); return false; }
+    if(X.n_rows != means.n_rows)  { arma_warn(3, "gmm_full::learn(): dimensionality mismatch"); return false; }
     
     // TODO: also check for number of vectors?
     }
   else
     {
-    if(X.n_cols < N_gaus)  { arma_debug_warn_level(3, "gmm_full::learn(): number of vectors is less than number of gaussians"); return false; }
+    if(X.n_cols < N_gaus)  { arma_warn(3, "gmm_full::learn(): number of vectors is less than number of gaussians"); return false; }
     
     reset(X.n_rows, N_gaus);
     
@@ -790,7 +790,7 @@ gmm_full<eT>::learn
     
     stream_state.restore(get_cout_stream());
     
-    if(status == false)  { arma_debug_warn_level(3, "gmm_full::learn(): k-means algorithm failed; not enough data, or too many gaussians requested"); init(orig); return false; }
+    if(status == false)  { arma_warn(3, "gmm_full::learn(): k-means algorithm failed; not enough data, or too many gaussians requested"); init(orig); return false; }
     }
   
   
@@ -817,7 +817,7 @@ gmm_full<eT>::learn
     
     stream_state.restore(get_cout_stream());
     
-    if(status == false)  { arma_debug_warn_level(3, "gmm_full::learn(): EM algorithm failed"); init(orig); return false; }
+    if(status == false)  { arma_warn(3, "gmm_full::learn(): EM algorithm failed"); init(orig); return false; }
     }
   
   mah_aux.reset();
@@ -840,7 +840,7 @@ inline
 void
 gmm_full<eT>::init(const gmm_full<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   gmm_full<eT>& t = *this;
   
@@ -861,7 +861,7 @@ inline
 void
 gmm_full<eT>::init(const gmm_diag<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   access::rw(hefts) = x.hefts;
   access::rw(means) = x.means;
@@ -893,7 +893,7 @@ inline
 void
 gmm_full<eT>::init(const uword in_n_dims, const uword in_n_gaus)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   access::rw(means).zeros(in_n_dims, in_n_gaus);
   
@@ -917,7 +917,7 @@ inline
 void
 gmm_full<eT>::init_constants(const bool calc_chol)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -1026,7 +1026,7 @@ inline
 umat
 gmm_full<eT>::internal_gen_boundaries(const uword N) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   #if defined(ARMA_USE_OPENMP)
     const uword n_threads_avail = uword(omp_get_max_threads());
@@ -1073,7 +1073,7 @@ inline
 eT
 gmm_full<eT>::internal_scalar_log_p(const eT* x) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const eT* log_hefts_mem = log_hefts.mem;
   
@@ -1087,7 +1087,7 @@ gmm_full<eT>::internal_scalar_log_p(const eT* x) const
       {
       const eT log_val = internal_scalar_log_p(x, g) + log_hefts_mem[g];
       
-      log_sum = log_add_exp(log_sum, log_val);
+      log_sum = priv::internal_log_add_exp(log_sum, log_val);
       }
     
     return log_sum;
@@ -1105,7 +1105,7 @@ inline
 eT
 gmm_full<eT>::internal_scalar_log_p(const eT* x, const uword g) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims   = means.n_rows;
   const eT*   mean_mem = means.colptr(g);
@@ -1138,12 +1138,12 @@ inline
 Row<eT>
 gmm_full<eT>::internal_vec_log_p(const Mat<eT>& X) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims    = means.n_rows;
   const uword N_samples = X.n_cols;
   
-  arma_debug_check( (X.n_rows != N_dims), "gmm_full::log_p(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != N_dims), "gmm_full::log_p(): incompatible dimensions" );
   
   Row<eT> out(N_samples, arma_nozeros_indicator());
   
@@ -1191,13 +1191,13 @@ inline
 Row<eT>
 gmm_full<eT>::internal_vec_log_p(const Mat<eT>& X, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims    = means.n_rows;
   const uword N_samples = X.n_cols;
   
-  arma_debug_check( (X.n_rows != N_dims),       "gmm_full::log_p(): incompatible dimensions"            );
-  arma_debug_check( (gaus_id  >= means.n_cols), "gmm_full::log_p(): specified gaussian is out of range" );
+  arma_conform_check( (X.n_rows != N_dims),       "gmm_full::log_p(): incompatible dimensions"            );
+  arma_conform_check( (gaus_id  >= means.n_cols), "gmm_full::log_p(): specified gaussian is out of range" );
   
   Row<eT> out(N_samples, arma_nozeros_indicator());
   
@@ -1245,9 +1245,9 @@ inline
 eT
 gmm_full<eT>::internal_sum_log_p(const Mat<eT>& X) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_full::sum_log_p(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_full::sum_log_p(): incompatible dimensions" );
     
   const uword N = X.n_cols;
   
@@ -1301,10 +1301,10 @@ inline
 eT
 gmm_full<eT>::internal_sum_log_p(const Mat<eT>& X, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_full::sum_log_p(): incompatible dimensions"            );
-  arma_debug_check( (gaus_id  >= means.n_cols), "gmm_full::sum_log_p(): specified gaussian is out of range" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_full::sum_log_p(): incompatible dimensions"            );
+  arma_conform_check( (gaus_id  >= means.n_cols), "gmm_full::sum_log_p(): specified gaussian is out of range" );
     
   const uword N = X.n_cols;
   
@@ -1358,12 +1358,12 @@ inline
 eT
 gmm_full<eT>::internal_avg_log_p(const Mat<eT>& X) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims    = means.n_rows;
   const uword N_samples = X.n_cols;
   
-  arma_debug_check( (X.n_rows != N_dims), "gmm_full::avg_log_p(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != N_dims), "gmm_full::avg_log_p(): incompatible dimensions" );
   
   if(N_samples == 0)  { return (-Datum<eT>::inf); }
   
@@ -1426,13 +1426,13 @@ inline
 eT
 gmm_full<eT>::internal_avg_log_p(const Mat<eT>& X, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims    = means.n_rows;
   const uword N_samples = X.n_cols;
   
-  arma_debug_check( (X.n_rows != N_dims),       "gmm_full::avg_log_p(): incompatible dimensions"            );
-  arma_debug_check( (gaus_id  >= means.n_cols), "gmm_full::avg_log_p(): specified gaussian is out of range" );
+  arma_conform_check( (X.n_rows != N_dims),       "gmm_full::avg_log_p(): incompatible dimensions"            );
+  arma_conform_check( (gaus_id  >= means.n_cols), "gmm_full::avg_log_p(): specified gaussian is out of range" );
   
   if(N_samples == 0)  { return (-Datum<eT>::inf); }
   
@@ -1495,13 +1495,13 @@ inline
 uword
 gmm_full<eT>::internal_scalar_assign(const Mat<eT>& X, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
   
-  arma_debug_check( (X.n_rows != N_dims), "gmm_full::assign(): incompatible dimensions" );
-  arma_debug_check( (N_gaus == 0),        "gmm_full::assign(): model has no means"      );
+  arma_conform_check( (X.n_rows != N_dims), "gmm_full::assign(): incompatible dimensions" );
+  arma_conform_check( (N_gaus == 0),        "gmm_full::assign(): model has no means"      );
   
   const eT* X_mem = X.colptr(0);
   
@@ -1546,7 +1546,7 @@ gmm_full<eT>::internal_scalar_assign(const Mat<eT>& X, const gmm_dist_mode& dist
     }
   else
     {
-    arma_debug_check(true, "gmm_full::assign(): unsupported distance mode");
+    arma_conform_check(true, "gmm_full::assign(): unsupported distance mode");
     }
   
   return uword(0);
@@ -1559,12 +1559,12 @@ inline
 void
 gmm_full<eT>::internal_vec_assign(urowvec& out, const Mat<eT>& X, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
   
-  arma_debug_check( (X.n_rows != N_dims), "gmm_full::assign(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != N_dims), "gmm_full::assign(): incompatible dimensions" );
   
   const uword X_n_cols = (N_gaus > 0) ? X.n_cols : 0;
   
@@ -1675,7 +1675,7 @@ gmm_full<eT>::internal_vec_assign(urowvec& out, const Mat<eT>& X, const gmm_dist
     }
   else
     {
-    arma_debug_check(true, "gmm_full::assign(): unsupported distance mode");
+    arma_conform_check(true, "gmm_full::assign(): unsupported distance mode");
     }
   }
 
@@ -1687,7 +1687,7 @@ inline
 void
 gmm_full<eT>::internal_raw_hist(urowvec& hist, const Mat<eT>& X, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -1832,7 +1832,7 @@ inline
 void
 gmm_full<eT>::generate_initial_means(const Mat<eT>& X, const gmm_seed_mode& seed_mode)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -1926,7 +1926,7 @@ inline
 void
 gmm_full<eT>::generate_initial_params(const Mat<eT>& X, const eT var_floor)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -2081,7 +2081,7 @@ inline
 bool
 gmm_full<eT>::km_iterate(const Mat<eT>& X, const uword max_iter, const bool verbose)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(verbose)
     {
@@ -2321,7 +2321,7 @@ inline
 bool
 gmm_full<eT>::em_iterate(const Mat<eT>& X, const uword max_iter, const eT var_floor, const bool verbose)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -2433,7 +2433,7 @@ gmm_full<eT>::em_update_params
   const eT                 var_floor
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword n_threads = boundaries.n_cols;
   
@@ -2588,7 +2588,7 @@ gmm_full<eT>::em_generate_acc
   )
   const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   progress_log_lhood = eT(0);
   
@@ -2618,7 +2618,7 @@ gmm_full<eT>::em_generate_acc
     
     for(uword g=1; g < N_gaus; ++g)
       {
-      log_lhood_sum = log_add_exp(log_lhood_sum, gaus_log_lhoods_mem[g]);
+      log_lhood_sum = priv::internal_log_add_exp(log_lhood_sum, gaus_log_lhoods_mem[g]);
       }
     
     progress_log_lhood += log_lhood_sum;
@@ -2672,7 +2672,7 @@ inline
 void
 gmm_full<eT>::em_fix_params(const eT var_floor)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
